@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: Run Kwalitee tests including optional indicators, especially, prereq_matches_use
-our $VERSION = 'v0.3.0'; # VERSION
+our $VERSION = 'v0.3.1'; # VERSION
 
 use version 0.77;
 use Cwd;
@@ -64,7 +64,7 @@ sub _pmu_error_desc
 	}
 	$error   ||= q{This distribution uses a module or a dist that's not listed as a prerequisite.};
 	$remedy  ||= q{List all used modules in META.yml requires};
-	$berror  ||= q{This distribution uses a module or a dist in it's test suite that's not listed as a build prerequisite.};
+	$berror  ||= q{This distribution uses a module or a dist in its test suite that's not listed as a build prerequisite.};
 	$bremedy ||= q{List all modules used in the test suite in META.yml build_requires};
 
 	return ($error, $remedy, $berror, $bremedy);
@@ -425,7 +425,7 @@ Test::Kwalitee::Extra - Run Kwalitee tests including optional indicators, especi
 
 =head1 VERSION
 
-version v0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
@@ -768,7 +768,7 @@ Yasutaka ATARASHI <yakex@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Yasutaka ATARASHI.
+This software is copyright (c) 2015 by Yasutaka ATARASHI.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
